@@ -1,3 +1,5 @@
+from dungeonsheets.features.features import Feature, create_feature, all_features
+
 from dungeonsheets.features.artificer import *
 from dungeonsheets.features.backgrounds import *
 from dungeonsheets.features.barbarian import *
@@ -5,7 +7,6 @@ from dungeonsheets.features.bard import *
 from dungeonsheets.features.cleric import *
 from dungeonsheets.features.druid import *
 from dungeonsheets.features.feats import *
-from dungeonsheets.features.features import Feature, create_feature
 from dungeonsheets.features.fighter import *
 from dungeonsheets.features.monk import *
 from dungeonsheets.features.paladin import *
