@@ -4,6 +4,8 @@ game mechanics."""
 from dungeonsheets.spells import Spell
 from dungeonsheets.features import Feature
 from dungeonsheets.infusions import Infusion
-from dungeonsheets.weapons import Weapon
+from dungeonsheets.weapons import Weapon, MeleeWeapon, RangedWeapon, SimpleWeapon, MartialWeapon
 from dungeonsheets.armor import Armor, Shield
 from dungeonsheets.magic_items import MagicItem
+from dungeonsheets.monsters import Monster
+from dungeonsheets.stats import Ability
