@@ -12,21 +12,25 @@ class LegendLore(Spell):
     The information you
     learn is accurate but might be couched in figurative language. For example, if
     you have a mysterious magic axe on hand, the spell might yield this information:
-     Woe to the evildoer whose hand touches the axe, for even the haft slices the
+    Woe to the evildoer whose hand touches the axe, for even the haft slices the
     hand of the evil ones. Only a true Child of Stone, lover and beloved of Moradin,
-     may awaken the true powers of the axe, and only with the sacred word Rudnogg on
-     the lips.
+    may awaken the true powers of the axe, and only with the sacred word Rudnogg on
+    the lips.
     """
+
     name = "Legend Lore"
     level = 5
     casting_time = "10 minutes"
     casting_range = "Self"
-    components = ('V', 'S', 'M')
-    materials = """Incense worth at least 250 gp, which the spell consumes, and four ivory strips worth at least 50 gp each"""
+    components = ("V", "S", "M")
+    materials = (
+        "Incense worth at least 250 gp, which the spell consumes, and four ivory strips"
+        " worth at least 50 gp each"
+    )
     duration = "Instantaneous"
     ritual = False
     magic_school = "Divination"
-    classes = ('Bard', 'Cleric', 'Wizard')
+    classes = ("Bard", "Cleric", "Wizard")
 
 
 class LeomundsSecretChest(Spell):
@@ -39,25 +43,30 @@ class LeomundsSecretChest(Spell):
     While the chest remains on the Ethereal Plane, you can
     use an action and touch the replica to recall the chest. It appears in an
     unoccupied space on the ground within 5 feet of you. You can send the chest back
-     to the Ethereal Plane by using an action and touching both the chest and the
+    to the Ethereal Plane by using an action and touching both the chest and the
     replica.
 
     After 60 days, there is a cumulative 5 percent chance per day that the
-     spell's effect ends. This effect ends if you cast this spell again, if the
+    spell's effect ends. This effect ends if you cast this spell again, if the
     smaller replica chest is destroyed, or if you choose to end the spell as an
     action. If the spell ends and the larger chest is on the Ethereal Plane, it is
     irretrievably lost.
     """
+
     name = "Leomunds Secret Chest"
     level = 4
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """An exquisite chest, 3 feet by 2 feet by 2 feet, constructed from rare materials worth at least 5,000 gp, and a tiny replica made from the same materials worth at least 50 gp"""
+    components = ("V", "S", "M")
+    materials = (
+        "An exquisite chest, 3 feet by 2 feet by 2 feet, constructed from rare"
+        " materials worth at least 5,000 gp, and a tiny replica made from the same"
+        " materials worth at least 50 gp"
+    )
     duration = "Instantaneous"
     ritual = False
     magic_school = "Conjuration"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class LeomundsTinyHut(Spell):
@@ -70,39 +79,41 @@ class LeomundsTinyHut(Spell):
     creatures. Creatures and objects within the dome when you cast this spell can
     move through it freely. All other creatures and objects are barred from passing
     through it. Spells and other magical effects can't extend through the dome or be
-     cast through it. The atmosphere inside the space is comfortable and dry,
+    cast through it. The atmosphere inside the space is comfortable and dry,
     regardless of the weather outside.
 
     Until the spell ends, you can command the
     interior to become dimly lit or dark. The dome is opaque from the outside, of
     any color you choose, but it is transparent from the inside.
     """
+
     name = "Leomunds Tiny Hut"
     level = 3
     casting_time = "1 minute"
     casting_range = "Self (10-foot-radius hemisphere)"
-    components = ('V', 'S', 'M')
-    materials = """A small crystal bead"""
+    components = ("V", "S", "M")
+    materials = "A small crystal bead"
     duration = "8 hours"
     ritual = True
     magic_school = "Evocation"
-    classes = ('Bard', 'Wizard')
+    classes = ("Bard", "Wizard")
 
 
 class LesserRestoration(Spell):
     """You touch a creature and can end either one disease or one condition afflicting
     it. The condition can be blinded, deafened, paralyzed, or poisoned.
     """
+
     name = "Lesser Restoration"
     level = 2
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Bard', 'Cleric', 'Druid', 'Paladin', 'Ranger')
+    classes = ("Bard", "Cleric", "Druid", "Paladin", "Ranger")
 
 
 class Levitate(Spell):
@@ -112,8 +123,8 @@ class Levitate(Spell):
     that succeeds on a Constitution saving throw is unaffected.
 
     The target can move
-     only by pushing or pulling against a fixed object or surface within reach (such
-     as a wall or a ceiling), which allows it to move as if it were climbing. You
+    only by pushing or pulling against a fixed object or surface within reach (such
+    as a wall or a ceiling), which allows it to move as if it were climbing. You
     can change the target's altitude by up to 20 feet in either direction on your
     turn. If you are the target, you can move up or down as part of your move.
     Otherwise, you can use your action to move the target, which must remain within
@@ -122,16 +133,20 @@ class Levitate(Spell):
     When the spell ends, the target floats gently to the ground
     if it is still aloft.
     """
+
     name = "Levitate"
     level = 2
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S', 'M')
-    materials = """Either a small leather loop or a piece of golden wire bent into a cup shape with a long shank on one end"""
+    components = ("V", "S", "M")
+    materials = (
+        "Either a small leather loop or a piece of golden wire bent into a cup shape"
+        " with a long shank on one end"
+    )
     duration = "Concentration, up to 10 minutes"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class LifeTransference(Spell):
@@ -140,42 +155,44 @@ class LifeTransference(Spell):
     range regains a number of hit points equal to twice the necrotic damage you
     take.
 
-    At Higher Levels: When you cast this spell using a spell slot of 4th
+    **At Higher Levels:** When you cast this spell using a spell slot of 4th
     level or higher, the damage increases by 1d8 for each slot level above 3rd.
     """
+
     name = "Life Transference"
     level = 3
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Cleric', 'Wizard')
+    classes = ("Cleric", "Wizard")
 
 
 class Light(Spell):
     """You touch one object that is no larger than 10 feet in any dimension. Until the
     spell ends, the object sheds bright light in a 20-foot radius and dim light for
     an additional 20 feet. The light can be colored as you like. Completely covering
-     the object with something opaque blocks the light. The spell ends if you cast
+    the object with something opaque blocks the light. The spell ends if you cast
     it again or dismiss it as an action.
 
     If you target an object held or worn by a
     hostile creature, that creature must succeed on a Dexterity saving throw to
     avoid the spell.
     """
+
     name = "Light"
     level = 0
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'M')
-    materials = """A firefly or phosphorescent moss"""
+    components = ("V", "M")
+    materials = "A firefly or phosphorescent moss"
     duration = "1 hour"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Bard', 'Cleric', 'Sorcerer', 'Wizard')
+    classes = ("Bard", "Cleric", "Sorcerer", "Wizard")
 
 
 class LightningArrow(Spell):
@@ -197,41 +214,43 @@ class LightningArrow(Spell):
     higher, the damage for both effects of the spell increases by 1d8 for each slot
     level above 3rd.
     """
+
     name = "Lightning Arrow"
     level = 3
     casting_time = "1 bonus action"
     casting_range = "Self"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Ranger',)
+    classes = ("Ranger",)
 
 
 class LightningBolt(Spell):
     """A stroke of lightning forming a line of 100 feet long and 5 feet wide blasts out
-     from you in a direction you choose. Each creature in the line must make a
+    from you in a direction you choose. Each creature in the line must make a
     Dexterity saving throw. A creature takes 8d6 lightning damage on a failed save,
     or half as much damage on a successful one.
 
     The lightning ignites flammable
     objects in the area that aren't being worn or carried.
 
-    At Higher Levels: When
+    **At Higher Levels:** When
     you cast this spell using a spell slot of 4th level or higher, the damage
     increases by 1d6 for each slot level above 3rd.
     """
+
     name = "Lightning Bolt"
     level = 3
     casting_time = "1 action"
     casting_range = "Self (100-foot line)"
-    components = ('V', 'S', 'M')
-    materials = """A bit of fur and a rod of amber, crystal, or glass"""
+    components = ("V", "S", "M")
+    materials = "A bit of fur and a rod of amber, crystal, or glass"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class LightningLure(Spell):
@@ -241,20 +260,21 @@ class LightningLure(Spell):
     saving throw or be pulled up to 10 feet in a straight line toward you and then
     take 1d8 lightning damage if it is within 5 feet of you.
 
-    At Higher Levels: This
-     spell's damage increases by 1d8 when you reach 5th level (2d8), 11th level
+    **At Higher Levels:** This
+    spell's damage increases by 1d8 when you reach 5th level (2d8), 11th level
     (3d8), and 17th level (4d8).
     """
+
     name = "Lightning Lure"
     level = 0
     casting_time = "1 action"
     casting_range = "15 feet"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Sorcerer", "Warlock", "Wizard")
 
 
 class LocateAnimalsOrPlants(Spell):
@@ -262,16 +282,17 @@ class LocateAnimalsOrPlants(Spell):
     of nature in your surroundings, you learn the direction and distance to the
     closest creature or plant of that kind within 5 miles, if any are present.
     """
+
     name = "Locate Animals Or Plants"
     level = 2
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S', 'M')
-    materials = """A bit of fur from a bloodhound"""
+    components = ("V", "S", "M")
+    materials = "A bit of fur from a bloodhound"
     duration = "Instantaneous"
     ritual = True
     magic_school = "Divination"
-    classes = ('Bard', 'Druid', 'Ranger')
+    classes = ("Bard", "Druid", "Ranger")
 
 
 class LocateCreature(Spell):
@@ -290,16 +311,17 @@ class LocateCreature(Spell):
     locate a creature if running water at least 10 feet wide blocks a direct path
     between you and the creature.
     """
+
     name = "Locate Creature"
     level = 4
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S', 'M')
-    materials = """A bit of fur from a bloodhound"""
+    components = ("V", "S", "M")
+    materials = "A bit of fur from a bloodhound"
     duration = "Concentration, up to 1 hour"
     ritual = False
     magic_school = "Divination"
-    classes = ('Bard', 'Cleric', 'Druid', 'Paladin', 'Ranger', 'Wizard')
+    classes = ("Bard", "Cleric", "Druid", "Paladin", "Ranger", "Wizard")
 
 
 class LocateObject(Spell):
@@ -316,35 +338,35 @@ class LocateObject(Spell):
     This spell can't locate an object if any thickness
     of lead, even a thin sheet, blocks a direct path between you and the object.
     """
+
     name = "Locate Object"
     level = 2
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S', 'M')
-    materials = """A forked twig"""
+    components = ("V", "S", "M")
+    materials = "A forked twig"
     duration = "Concentration, up to 10 minutes"
     ritual = False
     magic_school = "Divination"
-    classes = ('Bard', 'Cleric', 'Druid', 'Paladin', 'Ranger', 'Wizard')
+    classes = ("Bard", "Cleric", "Druid", "Paladin", "Ranger", "Wizard")
 
 
 class Longstrider(Spell):
     """You touch a creature. The target's speed increases by 10 feet until the spell
     ends.
 
-    At Higher Levels: When you cast this spell using a spell slot of 2nd
+    **At Higher Levels:** When you cast this spell using a spell slot of 2nd
     level or higher, you can target one additional creature for each slot level
     above 1st.
     """
+
     name = "Longstrider"
     level = 1
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A pinch of dirt"""
+    components = ("V", "S", "M")
+    materials = "A pinch of dirt"
     duration = "1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Bard', 'Druid', 'Ranger', 'Wizard')
-
-
+    classes = ("Bard", "Druid", "Ranger", "Wizard")
